Module cli

Module cli 

Structs

Cli
A CLI application to traverse files in a folder and concatenate them into a single text file, suitable for GenAI model input.
JoinArgs
Defines the arguments for the ‘join’ subcommand.
UpdateArgs
Defines the arguments for the ‘update’ subcommand. Currently a placeholder.

Enums

Commands
Defines the available subcommands for the application.