Module walker

Module walker 

Functions

find_files
This module is responsible for efficiently finding all files that match the user’s criteria using the ignore crate, which is excellent at respecting rules like .gitignore and handling parallel directory traversal.